@@ -2,7 +2,7 @@
  * -*- coding: utf-8; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=c:et:sw=4:ts=4:sts=4:tw=100
  * libmachista.c
  *
- * Copyright (c) 2011 The MacPorts Project
+ * Copyright (c) 2011-2012, 2014, 2016-2018 The MacPorts Project
  * Copyright (c) 2011 Landon Fuller <landonf@macports.org>
  * Copyright (c) 2011 Clemens Lang <cal@macports.org>
  * All rights reserved.
@@ -33,7 +33,7 @@
 #include <config.h>
 #endif
 
-/* required for asprintf(3) on OS X */
+/* required for asprintf(3) on macOS */
 #define _DARWIN_C_SOURCE
 /* required for asprintf(3) on Linux */
 #define _GNU_SOURCE
@@ -55,7 +55,9 @@
 #include <mach-o/fat.h>
 #include <mach-o/loader.h>
 
-#include <libkern/OSAtomic.h>
+#include <libkern/OSByteOrder.h>
+
+#include <dlfcn.h>
 #endif
 
 #include "libmachista.h"
@@ -465,6 +467,11 @@ int macho_parse_file(macho_handle_t *handle, const char *filepath, const macho_t
     
     /* Open input file */
     if ((fd = open(filepath, O_RDONLY)) < 0) {
+#ifdef HAVE_DLOPEN_PREFLIGHT
+        if (dlopen_preflight(filepath)) {
+            return MACHO_ECACHE;
+        }
+#endif /* HAVE_DLOPEN_PREFLIGHT */
         return MACHO_EFILE;
     }
 
@@ -559,6 +566,7 @@ const char *macho_strerror(int err) {
         /* 0x04 */ "Error allocating memory",
         /* 0x08 */ "Premature end of data, possibly corrupt file",
         /* 0x10 */ "Not a Mach-O file",
+        /* 0x20 */ "Shared cache only",
     };
     return errors[num];
 }
