@@ -323,30 +323,27 @@ proc portconfigure::configure_start {args} {
 
     set compiler [option configure.compiler]
     set valid_compilers {
-        {^apple-gcc-(4\.[02])$}             {MacPorts Apple GCC %s}
-        {^cc$}                              {System cc}
-        {^clang$}                           {Xcode Clang}
-        {^gcc$}                             {System GCC}
-        {^gcc-(3\.3|4\.[02])$}              {Xcode GCC %s}
-        {^llvm-gcc-4\.2$}                   {Xcode LLVM-GCC 4.2}
-        {^macports-clang$}                  {MacPorts Clang (port select)}
-        {^macports-clang-(\d+\.\d+)$}       {MacPorts Clang %s}
-        {^macports-gcc$}                    {MacPorts GCC (port select)}
-        {^macports-gcc-(\d+(?:\.\d+)?)$}    {MacPorts GCC %s}
-        {^macports-llvm-gcc-4\.2$}          {MacPorts LLVM-GCC 4.2}
-        {^macports-g95$}                    {MacPorts G95}
-        {^macports-mpich-default$}          {MacPorts MPICH Wrapper for MacPorts' Default C/C++ Compiler}
-        {^macports-openmpi-default$}        {MacPorts Open MPI Wrapper for MacPorts' Default C/C++ Compiler}
-        {^macports-mpich-clang$}            {MacPorts MPICH Wrapper for Xcode Clang}
-        {^macports-openmpi-clang$}          {MacPorts Open MPI Wrapper for Xcode Clang}
-        {^macports-mpich-clang-(\d+\.\d+)$}
-            {MacPorts MPICH Wrapper for Clang %s}
-        {^macports-openmpi-clang-(\d+\.\d+)$}
-            {MacPorts Open MPI Wrapper for Clang %s}
-        {^macports-mpich-gcc-(\d+(?:\.\d+)?)$}
-            {MacPorts MPICH Wrapper for GCC %s}
-        {^macports-openmpi-gcc-(\d+(?:\.\d+)?)$}
-            {MacPorts Open MPI Wrapper for GCC %s}
+        {^apple-gcc-(4\.[02])$}                    {MacPorts Apple GCC %s}
+        {^cc$}                                     {System cc}
+        {^clang$}                                  {Xcode Clang}
+        {^gcc$}                                    {System GCC}
+        {^gcc-(3\.3|4\.[02])$}                     {Xcode GCC %s}
+        {^llvm-gcc-4\.2$}                          {Xcode LLVM-GCC 4.2}
+        {^macports-clang$}                         {MacPorts Clang (port select)}
+        {^macports-clang-(\d+(?:\.\d+)?)$}         {MacPorts Clang %s}
+        {^macports-gcc$}                           {MacPorts GCC (port select)}
+        {^macports-gcc-(\d+(?:\.\d+)?)$}           {MacPorts GCC %s}
+        {^macports-llvm-gcc-4\.2$}                 {MacPorts LLVM-GCC 4.2}
+        {^macports-g95$}                           {MacPorts G95}
+        {^macports-mpich-default$}                 {MacPorts MPICH Wrapper for MacPorts' Default C/C++ Compiler}
+        {^macports-openmpi-default$}               {MacPorts Open MPI Wrapper for MacPorts' Default C/C++ Compiler}
+        {^macports-mpich-clang$}                   {MacPorts MPICH Wrapper for Xcode Clang}
+        {^macports-openmpi-clang$}                 {MacPorts Open MPI Wrapper for Xcode Clang}
+        {^macports-mpich-clang-(\d+(?:\.\d+)?)$}   {MacPorts MPICH Wrapper for Clang %s}
+        {^macports-openmpi-clang-(\d+(?:\.\d+)?)$} {MacPorts Open MPI Wrapper for Clang %s}
+        {^macports-mpich-gcc-(\d+(?:\.\d+)?)$}     {MacPorts MPICH Wrapper for GCC %s}
+        {^macports-openmpi-gcc-(\d+(?:\.\d+)?)$}   {MacPorts Open MPI Wrapper for GCC %s}
+        {^macports-(clang|gcc)-devel$}             {MacPorts %s Development}
     }
     foreach {re fmt} $valid_compilers {
         if {[set matches [regexp -inline $re $compiler]] ne ""} {
@@ -388,26 +385,61 @@ proc portconfigure::configure_start {args} {
 
 # internal function to choose the default configure.build_arch and
 # configure.universal_archs based on supported_archs and build_arch or
-# universal_archs
+# universal_archs, plus the SDK being used
 proc portconfigure::choose_supported_archs {archs} {
     global supported_archs configure.sdk_version
-    # macOS 10.14 SDK only supports one arch, x86_64
-    if {${configure.sdk_version} ne "" && [vercmp ${configure.sdk_version} 10.14] >= 0} {
-        if {"x86_64" in $archs && ($supported_archs eq "" || "x86_64" in $supported_archs)} {
-            return x86_64
+
+    if {${configure.sdk_version} ne ""} {
+        # Figure out which archs are supported by the SDK
+        if {[vercmp ${configure.sdk_version} 11.0] >= 0} {
+            set sdk_archs [list arm64 x86_64]
+        } elseif {[vercmp ${configure.sdk_version} 10.14] >= 0} {
+            set sdk_archs x86_64
+        } elseif {[vercmp ${configure.sdk_version} 10.7] >= 0} {
+            set sdk_archs [list x86_64 i386]
+        } elseif {[vercmp ${configure.sdk_version} 10.6] >= 0} {
+            set sdk_archs [list x86_64 i386 ppc]
+        } elseif {[vercmp ${configure.sdk_version} 10.5] >= 0} {
+            set sdk_archs [list x86_64 i386 ppc ppc64]
         } else {
-            return ""
+            # 10.4u
+            set sdk_archs [list i386 ppc ppc64]
+        }
+
+        # Set intersection_archs to the intersection of what's supported by
+        # the SDK and the port's supported_archs
+        if {$supported_archs eq ""} {
+            # Blank supported_archs; allow whatever the SDK does.
+            set intersection_archs $sdk_archs
+        } else {
+            set intersection_archs [list]
+            foreach arch $sdk_archs {
+                if {$arch in $supported_archs} {
+                    lappend intersection_archs $arch
+                }
+            }
+            if {$intersection_archs eq ""} {
+                # No archs in common.
+                return ""
+            }
         }
     } elseif {$supported_archs eq ""} {
+        # Nothing to filter on.
         return $archs
+    } else {
+        # No SDK version (maybe not on macOS)
+        set intersection_archs $supported_archs
     }
     set ret {}
+    # Filter out unsupported archs, but allow demoting to 32-bit if needed.
+    # That means if build_arch is x86_64 it's still possible to build a port
+    # that sets supported_archs to "i386 ppc" if the SDK allows it.
     foreach arch $archs {
-        if {$arch in $supported_archs} {
+        if {$arch in $intersection_archs} {
             set add_arch $arch
-        } elseif {$arch eq "x86_64" && "i386" in $supported_archs} {
+        } elseif {$arch eq "x86_64" && "i386" in $intersection_archs} {
             set add_arch "i386"
-        } elseif {$arch eq "ppc64" && "ppc" in $supported_archs} {
+        } elseif {$arch eq "ppc64" && "ppc" in $intersection_archs} {
             set add_arch "ppc"
         } else {
             continue
@@ -455,7 +487,7 @@ proc portconfigure::configure_get_ld_archflags {} {
 }
 
 proc portconfigure::configure_get_sdkroot {sdk_version} {
-    global developer_dir macosx_version xcodeversion os.arch os.platform use_xcode
+    global developer_dir macosx_version xcodeversion os.arch os.major os.platform use_xcode
 
     # This is only relevant for macOS
     if {${os.platform} ne "darwin"} {
@@ -468,7 +500,7 @@ proc portconfigure::configure_get_sdkroot {sdk_version} {
     }
 
     # Use the DevSDK (eg: /usr/include) if present and the requested SDK version matches the host version
-    if {$sdk_version eq $macosx_version && [file exists /usr/include]} {
+    if {${os.major} < 19 && $sdk_version eq $macosx_version && [file exists /usr/include/sys/cdefs.h]} {
         return {}
     }
 
@@ -613,14 +645,16 @@ proc portconfigure::arch_flag_supported {compiler {multiple_arch_flags no}} {
 
 proc portconfigure::compiler_port_name {compiler} {
     set valid_compiler_ports {
-        {^apple-gcc-(\d+)\.(\d+)$}                          {apple-gcc%s%s}
-        {^macports-clang-(\d+\.\d+)$}                       {clang-%s}
-        {^macports-(llvm-)?gcc-(\d+)(?:\.(\d+))?$}          {%sgcc%s%s}
+        {^apple-gcc-(\d+)\.(\d+)$}                                                    {apple-gcc%s%s}
+        {^macports-clang-(\d+(?:\.\d+)?)$}                                            {clang-%s}
+        {^macports-(llvm-)?gcc-(\d+)(?:\.(\d+))?$}                                    {%sgcc%s%s}
         {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-default$}                {%s-default}
         {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-clang$}                  {%s-clang}
         {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-clang-(\d+)\.(\d+)$}     {%s-clang%s%s}
+        {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-clang-(\d+)$}            {%s-clang%s}
         {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-gcc-(\d+)(?:\.(\d+))?$}  {%s-gcc%s%s}
-        {^macports-g95$}                                    {g95}
+        {^macports-g95$}                                                              {g95}
+        {^macports-(clang|gcc)-devel$}                                                {%s-devel}
     }
     foreach {re fmt} $valid_compiler_ports {
         if {[set matches [regexp -inline $re $compiler]] ne ""} {
@@ -719,6 +753,8 @@ proc portconfigure::max_version {verA verB} {
 }
 #
 # https://releases.llvm.org/3.1/docs/ClangReleaseNotes.html#cchanges
+# _Noreturn implemented in clang 3.3.0:
+# https://github.com/llvm/llvm-project/commit/debc59d1f360b1f7a041de72c02d76ed131370c6
 # https://gcc.gnu.org/c99status.html
 # https://gcc.gnu.org/wiki/C11Status
 # https://trac.macports.org/wiki/XcodeVersionInfo
@@ -727,7 +763,7 @@ proc portconfigure::max_version {verA verB} {
 #|------------------------------------------------------------------|
 #| 1989 (C89)   |     -     |        -      |     -     |     -     |
 #| 1999 (C99)   |     -     |        -      |     -     |    4.0    |
-#| 2011 (C11)   |    3.1    |    318.0.61   |    4.3    |    4.9    |
+#| 2011 (C11)   |    3.3    |   500.2.75    |    5.0    |    4.9    |
 #--------------------------------------------------------------------
 #
 # https://clang.llvm.org/cxx_status.html
@@ -740,7 +776,7 @@ proc portconfigure::max_version {verA verB} {
 #|--------------------------------=---------------------------------|
 #| 1998 (C++98) |     -     |       -       |     -     |     -     |
 #| 2011 (C++11) |    3.3    |   500.2.75    |    5.0    |   4.8.1   |
-#| 2014 (C++14) |    3.4    |   600.0.54    |    6.1    |     5     |
+#| 2014 (C++14) |    3.4    |   602         |    6.3    |     5     |
 #| 2017 (C++17) |    5.0    |   902.0.39.1  |    9.3    |     7     |
 #--------------------------------------------------------------------
 #
@@ -776,28 +812,34 @@ proc portconfigure::get_min_command_line {compiler} {
 
     switch ${compiler} {
         clang {
-            if {[option configure.cxx_stdlib] eq "libc++"} {
-                if {${os.major} < 11} {
-                    # no Xcode clang can build against libc++ on < 10.7
-                    return none
-                }
+            if {[option configure.cxx_stdlib] eq "libc++" && ${os.major} < 11} {
+                # no Xcode clang can build against libc++ on < 10.7
+                return none
             }
             if {${compiler.c_standard} >= 2011} {
-                set min_value [max_version $min_value 318.0.61]
+                set min_value [max_version $min_value 500.2.75]
             }
             if {${compiler.cxx_standard} >= 2017} {
                 set min_value [max_version $min_value 902.0.39.1]
             } elseif {${compiler.cxx_standard} >= 2014} {
-                set min_value [max_version $min_value 600.0.54]
+                set min_value [max_version $min_value 602]
             } elseif {${compiler.cxx_standard} >= 2011} {
-                set min_value [max_version $min_value 500.2.75]
+                if {${compiler.thread_local_storage}} {
+                    # macOS has supported thread-local storage since Mac OS X Lion.
+                    # So __thread (GNU extension) and _Thread_local (C11) could be used.
+                    # However, the C++11 keyword was not supported until Xcode 8
+                    #    (https://developer.apple.com/videos/play/wwdc2016-405/?time=354).
+                    set min_value [max_version $min_value 800.0.38]
+                } else {
+                    set min_value [max_version $min_value 500.2.75]
+                }
             }
         }
         llvm-gcc-4.2 -
         gcc-4.2 -
         gcc-4.0 -
         apple-gcc-4.2 {
-            if {${compiler.c_standard} > 1999 || ${compiler.cxx_standard} >= 2011 || [option configure.cxx_stdlib] eq "libc++"} {
+            if {${compiler.c_standard} > 1999 || ${compiler.cxx_standard} >= 2011 || [option configure.cxx_stdlib] eq "libc++" || ${compiler.thread_local_storage}} {
                 return none
             }
         }
@@ -818,9 +860,19 @@ proc portconfigure::get_min_clang {} {
     if {${compiler.cxx_standard} >= 2017} {
         set min_value [max_version $min_value 5.0]
     } elseif {${compiler.cxx_standard} >= 2014} {
-        set min_value [max_version $min_value 3.4]
+        if {[option configure.cxx_stdlib] eq "libc++"} {
+            set min_value [max_version $min_value 3.4]
+        } else {
+            # macports-libstdc++ only macports-clang compilers >= 5.0 support this
+            set min_value [max_version $min_value 5.0]
+        }
     } elseif {${compiler.cxx_standard} >= 2011} {
-        set min_value [max_version $min_value 3.3]
+        if {[option configure.cxx_stdlib] eq "libc++"} {
+            set min_value [max_version $min_value 3.3]
+        } else {
+            # macports-libstdc++ only macports-clang compilers >= 5.0 support this
+            set min_value [max_version $min_value 5.0]
+        }
     }
     if {[vercmp ${compiler.openmp_version} 4.0] >= 0} {
         set min_value [max_version $min_value 6.0]
@@ -837,7 +889,11 @@ proc portconfigure::get_min_clang {} {
 proc portconfigure::get_min_gcc {} {
     global compiler.c_standard compiler.cxx_standard compiler.openmp_version compiler.thread_local_storage
 
-    if {[option configure.cxx_stdlib] ne "" && [option configure.cxx_stdlib] ne "macports-libstdc++"} {
+    # Technically these only support macports-libstdc++, but if all the
+    # options that use the system libstdc++ have been blacklisted, we
+    # still need to use something. So only skip them entirely when
+    # using libc++.
+    if {[option configure.cxx_stdlib] eq "libc++"} {
         return none
     }
 
@@ -991,10 +1047,26 @@ proc portconfigure::get_clang_compilers {} {
         source ${compiler_file}
     } else {
         ui_debug "clang_compilers.tcl not found in ports tree, using built-in selections"
-        lappend compilers macports-clang-8.0 macports-clang-7.0 macports-clang-6.0 macports-clang-5.0
+        # clang 9.0 and older build on 10.6+ (darwin 10)
+        # clang 7.0 and older build on 10.5+ (darwin 9)
+        # clang 3.4 and older build on 10.4+ (darwin 8)
+        if {${os.major} >= 10} {
+            lappend compilers macports-clang-9.0 \
+                macports-clang-8.0
+        }
+
+        if {${os.major} >= 9} {
+            lappend compilers macports-clang-7.0 \
+                macports-clang-6.0 \
+                macports-clang-5.0
+        }
+
         if {${os.major} < 16} {
             # The Sierra SDK requires a toolchain that supports class properties
-            lappend compilers macports-clang-3.7 macports-clang-3.4
+            if {${os.major} >= 9} {
+                lappend compilers macports-clang-3.7
+            }
+            lappend compilers macports-clang-3.4
             if {${os.major} < 9} {
                 lappend compilers macports-clang-3.3
             }
@@ -1162,7 +1234,7 @@ proc portconfigure::find_developer_tool {name} {
 
 # internal function to find correct compilers
 proc portconfigure::configure_get_compiler {type {compiler {}}} {
-    global configure.compiler prefix
+    global configure.compiler prefix_frozen
     if {$compiler eq ""} {
         if {[option compiler.require_fortran]} {
             switch $type {
@@ -1183,14 +1255,14 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
     if {[regexp {^apple-gcc(-4\.[02])$} $compiler -> suffix]} {
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/gcc-apple${suffix} }
+            objc    { return ${prefix_frozen}/bin/gcc-apple${suffix} }
             cxx     -
             objcxx  {
                 if {$suffix eq "-4.2"} {
-                    return ${prefix}/bin/g++-apple${suffix}
+                    return ${prefix_frozen}/bin/g++-apple${suffix}
                 }
             }
-            cpp     { return ${prefix}/bin/cpp-apple${suffix} }
+            cpp     { return ${prefix_frozen}/bin/cpp-apple${suffix} }
         }
     } elseif {$compiler eq "clang"} {
         switch $type {
@@ -1227,18 +1299,18 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
         }
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/clang${suffix} }
+            objc    { return ${prefix_frozen}/bin/clang${suffix} }
             cxx     -
-            objcxx  { return ${prefix}/bin/clang++${suffix} }
+            objcxx  { return ${prefix_frozen}/bin/clang++${suffix} }
         }
-    } elseif {[regexp {^macports-clang(-\d+\.\d+)$} $compiler -> suffix]} {
+    } elseif {[regexp {^macports-clang(-\d+(?:\.\d+)?)$} $compiler -> suffix]} {
         set suffix "-mp${suffix}"
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/clang${suffix} }
+            objc    { return ${prefix_frozen}/bin/clang${suffix} }
             cxx     -
-            objcxx  { return ${prefix}/bin/clang++${suffix} }
-            cpp     { return ${prefix}/bin/clang-cpp${suffix} }
+            objcxx  { return ${prefix_frozen}/bin/clang++${suffix} }
+            cpp     { return ${prefix_frozen}/bin/clang-cpp${suffix} }
         }
     } elseif {[regexp {^macports-gcc(-\d+(?:\.\d+)?)?$} $compiler -> suffix]} {
         if {$suffix ne ""} {
@@ -1246,62 +1318,84 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
         }
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/gcc${suffix} }
+            objc    { return ${prefix_frozen}/bin/gcc${suffix} }
             cxx     -
-            objcxx  { return ${prefix}/bin/g++${suffix} }
-            cpp     { return ${prefix}/bin/cpp${suffix} }
+            objcxx  { return ${prefix_frozen}/bin/g++${suffix} }
+            cpp     { return ${prefix_frozen}/bin/cpp${suffix} }
             fc      -
             f77     -
-            f90     { return ${prefix}/bin/gfortran${suffix} }
+            f90     { return ${prefix_frozen}/bin/gfortran${suffix} }
+        }
+    } elseif {[regexp {^macports-(clang|gcc)-devel$} $compiler -> comp]} {
+        set suffix "-mp-devel"
+        if { $comp eq "clang" } {
+            switch $type {
+                cc      -
+                objc    { return ${prefix_frozen}/bin/clang${suffix} }
+                cxx     -
+                objcxx  { return ${prefix_frozen}/bin/clang++${suffix} }
+                cpp     { return ${prefix_frozen}/bin/clang-cpp${suffix} }
+            }
+        } else {
+            switch $type {
+                cc      -
+                objc    { return ${prefix_frozen}/bin/gcc${suffix} }
+                cxx     -
+                objcxx  { return ${prefix_frozen}/bin/g++${suffix} }
+                cpp     { return ${prefix_frozen}/bin/cpp${suffix} }
+                fc      -
+                f77     -
+                f90     { return ${prefix_frozen}/bin/gfortran${suffix} }
+            }
         }
     } elseif {$compiler eq "macports-llvm-gcc-4.2"} {
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/llvm-gcc-4.2 }
+            objc    { return ${prefix_frozen}/bin/llvm-gcc-4.2 }
             cxx     -
-            objcxx  { return ${prefix}/bin/llvm-g++-4.2 }
-            cpp     { return ${prefix}/bin/llvm-cpp-4.2 }
+            objcxx  { return ${prefix_frozen}/bin/llvm-g++-4.2 }
+            cpp     { return ${prefix_frozen}/bin/llvm-cpp-4.2 }
         }
     } elseif {$compiler eq "macports-g95"} {
         switch $type {
             fc      -
             f77     -
-            f90     { return ${prefix}/bin/g95 }
+            f90     { return ${prefix_frozen}/bin/g95 }
         }
     } elseif {[regexp {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-clang$} $compiler -> mpi]} {
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/mpicc-${mpi}-clang }
+            objc    { return ${prefix_frozen}/bin/mpicc-${mpi}-clang }
             cxx     -
-            objcxx  { return ${prefix}/bin/mpicxx-${mpi}-clang }
+            objcxx  { return ${prefix_frozen}/bin/mpicxx-${mpi}-clang }
         }
-    } elseif {[regexp {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-clang-(\d+\.\d+)$} $compiler -> mpi version]} {
+    } elseif {[regexp {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-clang-(\d+(?:\.\d+)?)$} $compiler -> mpi version]} {
         set suffix [join [split ${version} .] ""]
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/mpicc-${mpi}-clang${suffix} }
+            objc    { return ${prefix_frozen}/bin/mpicc-${mpi}-clang${suffix} }
             cxx     -
-            objcxx  { return ${prefix}/bin/mpicxx-${mpi}-clang${suffix} }
-            cpp     { return ${prefix}/bin/clang-cpp-mp-${version} }
+            objcxx  { return ${prefix_frozen}/bin/mpicxx-${mpi}-clang${suffix} }
+            cpp     { return ${prefix_frozen}/bin/clang-cpp-mp-${version} }
         }
     } elseif {[regexp {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-gcc-(\d+(?:\.\d+)?)$} $compiler -> mpi version]} {
         set suffix [join [split ${version} .] ""]
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/mpicc-${mpi}-gcc${suffix} }
+            objc    { return ${prefix_frozen}/bin/mpicc-${mpi}-gcc${suffix} }
             cxx     -
-            objcxx  { return ${prefix}/bin/mpicxx-${mpi}-gcc${suffix} }
-            cpp     { return ${prefix}/bin/cpp-mp-${version} }
+            objcxx  { return ${prefix_frozen}/bin/mpicxx-${mpi}-gcc${suffix} }
+            cpp     { return ${prefix_frozen}/bin/cpp-mp-${version} }
             fc      -
             f77     -
-            f90     { return ${prefix}/bin/mpifort-${mpi}-gcc${suffix} }
+            f90     { return ${prefix_frozen}/bin/mpifort-${mpi}-gcc${suffix} }
         }
     } elseif {[regexp {^macports-(mpich|openmpi|mpich-devel|openmpi-devel)-default$} $compiler -> mpi]} {
         switch $type {
             cc      -
-            objc    { return ${prefix}/bin/mpicc-${mpi}-mp }
+            objc    { return ${prefix_frozen}/bin/mpicc-${mpi}-mp }
             cxx     -
-            objcxx  { return ${prefix}/bin/mpicxx-${mpi}-mp }
+            objcxx  { return ${prefix_frozen}/bin/mpicxx-${mpi}-mp }
         }
     }
     # Fallbacks
@@ -1393,7 +1487,7 @@ proc portconfigure::add_compiler_port_dependencies {compiler} {
                 depends_lib-delete $libgcc_dep
                 depends_lib-append $libgcc_dep
             }
-        } elseif {[regexp {^macports-clang(?:-(\d+\.\d+))$} $compiler -> clang_version]} {
+        } elseif {[regexp {^macports-clang(?:-(\d+(?:\.\d+)?))$} $compiler -> clang_version]} {
             if {[option configure.cxx_stdlib] eq "macports-libstdc++"} {
                 # see https://trac.macports.org/ticket/54766
                 ui_debug "Adding depends_lib path:lib/libgcc/libgcc_s.1.dylib:libgcc"
@@ -1405,6 +1499,11 @@ proc portconfigure::add_compiler_port_dependencies {compiler} {
                 depends_lib-delete "port:libcxx"
                 depends_lib-append "port:libcxx"
             }
+            if {[option compiler.openmp_version] ne ""} {
+                ui_debug "Adding depends_lib port:libomp"
+                depends_lib-delete "port:libomp"
+                depends_lib-append "port:libomp"
+            }
         }
     }
 
